# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/audio/frame_aac.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%make87_messages/audio/frame_aac.proto\x12\x15make87_messages.audio\x1a!make87_messages/core/header.proto\"\xb6\x01\n\x08\x46rameAac\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\x12\x0b\n\x03pts\x18\x03 \x01(\x03\x12;\n\ttime_base\x18\x04 \x01(\x0b\x32(.make87_messages.audio.FrameAac.Fraction\x1a$\n\x08\x46raction\x12\x0b\n\x03num\x18\x01 \x01(\r\x12\x0b\n\x03\x64\x65n\x18\x02 \x01(\rb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.audio.frame_aac_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FRAMEAAC']._serialized_start=100
  _globals['_FRAMEAAC']._serialized_end=282
  _globals['_FRAMEAAC_FRACTION']._serialized_start=246
  _globals['_FRAMEAAC_FRACTION']._serialized_end=282
# @@protoc_insertion_point(module_scope)



from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Header(_message.Message):
    __slots__ = ("timestamp", "reference_id", "entity_path")
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    REFERENCE_ID_FIELD_NUMBER: _ClassVar[int]
    ENTITY_PATH_FIELD_NUMBER: _ClassVar[int]
    timestamp: _timestamp_pb2.Timestamp
    reference_id: int
    entity_path: str
    def __init__(self, timestamp: _Optional[_Union[_timestamp_pb2.Timestamp, _Mapping]] = ..., reference_id: _Optional[int] = ..., entity_path: _Optional[str] = ...) -> None: ...



from make87_messages.geometry.box import box_2d_aligned_pb2 as _box_2d_aligned_pb2
from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Boxes2DAxisAligned(_message.Message):
    __slots__ = ("header", "boxes")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    BOXES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    boxes: _containers.RepeatedCompositeFieldContainer[_box_2d_aligned_pb2.Box2DAxisAligned]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., boxes: _Optional[_Iterable[_Union[_box_2d_aligned_pb2.Box2DAxisAligned, _Mapping]]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DigestAlgorithm(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNSPECIFIED: _ClassVar[DigestAlgorithm]
    MD5: _ClassVar[DigestAlgorithm]
    MD5_SESS: _ClassVar[DigestAlgorithm]
    SHA_256: _ClassVar[DigestAlgorithm]
    SHA_256_SESS: _ClassVar[DigestAlgorithm]
    SHA_512_256: _ClassVar[DigestAlgorithm]
    SHA_512_256_SESS: _ClassVar[DigestAlgorithm]
UNSPECIFIED: DigestAlgorithm
MD5: DigestAlgorithm
MD5_SESS: DigestAlgorithm
SHA_256: DigestAlgorithm
SHA_256_SESS: DigestAlgorithm
SHA_512_256: DigestAlgorithm
SHA_512_256_SESS: DigestAlgorithm

class BasicAuth(_message.Message):
    __slots__ = ("header", "username", "password")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    username: str
    password: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., username: _Optional[str] = ..., password: _Optional[str] = ...) -> None: ...

class DigestAuth(_message.Message):
    __slots__ = ("header", "username", "password", "realm", "nonce", "opaque", "algorithm", "qop")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    USERNAME_FIELD_NUMBER: _ClassVar[int]
    PASSWORD_FIELD_NUMBER: _ClassVar[int]
    REALM_FIELD_NUMBER: _ClassVar[int]
    NONCE_FIELD_NUMBER: _ClassVar[int]
    OPAQUE_FIELD_NUMBER: _ClassVar[int]
    ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    QOP_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    username: str
    password: str
    realm: str
    nonce: str
    opaque: str
    algorithm: DigestAlgorithm
    qop: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., username: _Optional[str] = ..., password: _Optional[str] = ..., realm: _Optional[str] = ..., nonce: _Optional[str] = ..., opaque: _Optional[str] = ..., algorithm: _Optional[_Union[DigestAlgorithm, str]] = ..., qop: _Optional[str] = ...) -> None: ...

class BearerToken(_message.Message):
    __slots__ = ("header", "token")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    token: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., token: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/text/log_message.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&make87_messages/text/log_message.proto\x12\x14make87_messages.text\x1a!make87_messages/core/header.proto\"\xab\x02\n\nLogMessage\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x38\n\x05level\x18\x02 \x01(\x0e\x32).make87_messages.text.LogMessage.LogLevel\x12\x0f\n\x07message\x18\x03 \x01(\t\x12\x0e\n\x06source\x18\x04 \x01(\t\x12\x11\n\tfile_name\x18\x05 \x01(\t\x12\x13\n\x0bline_number\x18\x06 \x01(\x05\x12\x12\n\nprocess_id\x18\x07 \x01(\x03\x12\x11\n\tthread_id\x18\x08 \x01(\x03\"E\n\x08LogLevel\x12\t\n\x05\x44\x45\x42UG\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\x0b\n\x07WARNING\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\x0c\n\x08\x43RITICAL\x10\x04\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.text.log_message_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_LOGMESSAGE']._serialized_start=100
  _globals['_LOGMESSAGE']._serialized_end=399
  _globals['_LOGMESSAGE_LOGLEVEL']._serialized_start=330
  _globals['_LOGMESSAGE_LOGLEVEL']._serialized_end=399
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/primitive/sint32.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&make87_messages/primitive/sint32.proto\x12\x19make87_messages.primitive\x1a!make87_messages/core/header.proto\"E\n\x06SInt32\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05value\x18\x02 \x01(\x11\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.primitive.sint32_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_SINT32']._serialized_start=104
  _globals['_SINT32']._serialized_end=173
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/spatial/pose/pose_2d.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.spatial.translation import translation_2d_pb2 as make87__messages_dot_spatial_dot_translation_dot_translation__2d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*make87_messages/spatial/pose/pose_2d.proto\x12\x1cmake87_messages.spatial.pose\x1a!make87_messages/core/header.proto\x1a\x38make87_messages/spatial/translation/translation_2d.proto\"\x91\x01\n\x06Pose2D\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12G\n\x0btranslation\x18\x02 \x01(\x0b\x32\x32.make87_messages.spatial.translation.Translation2D\x12\x10\n\x08rotation\x18\x03 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.spatial.pose.pose_2d_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_POSE2D']._serialized_start=170
  _globals['_POSE2D']._serialized_end=315
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages.transport import endpoint_pb2 as _endpoint_pb2
from make87_messages.transport import auth_pb2 as _auth_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class RTSPMethod(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNSPECIFIED: _ClassVar[RTSPMethod]
    OPTIONS: _ClassVar[RTSPMethod]
    DESCRIBE: _ClassVar[RTSPMethod]
    SETUP: _ClassVar[RTSPMethod]
    PLAY: _ClassVar[RTSPMethod]
    PAUSE: _ClassVar[RTSPMethod]
    TEARDOWN: _ClassVar[RTSPMethod]
    GET_PARAMETER: _ClassVar[RTSPMethod]
    SET_PARAMETER: _ClassVar[RTSPMethod]
    RECORD: _ClassVar[RTSPMethod]
UNSPECIFIED: RTSPMethod
OPTIONS: RTSPMethod
DESCRIBE: RTSPMethod
SETUP: RTSPMethod
PLAY: RTSPMethod
PAUSE: RTSPMethod
TEARDOWN: RTSPMethod
GET_PARAMETER: RTSPMethod
SET_PARAMETER: RTSPMethod
RECORD: RTSPMethod

class RTSPRequest(_message.Message):
    __slots__ = ("header", "endpoint", "method", "headers", "basic_auth", "digest_auth")
    class HeadersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    HEADER_FIELD_NUMBER: _ClassVar[int]
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    METHOD_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    BASIC_AUTH_FIELD_NUMBER: _ClassVar[int]
    DIGEST_AUTH_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    endpoint: _endpoint_pb2.Endpoint
    method: RTSPMethod
    headers: _containers.ScalarMap[str, str]
    basic_auth: _auth_pb2.BasicAuth
    digest_auth: _auth_pb2.DigestAuth
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., endpoint: _Optional[_Union[_endpoint_pb2.Endpoint, _Mapping]] = ..., method: _Optional[_Union[RTSPMethod, str]] = ..., headers: _Optional[_Mapping[str, str]] = ..., basic_auth: _Optional[_Union[_auth_pb2.BasicAuth, _Mapping]] = ..., digest_auth: _Optional[_Union[_auth_pb2.DigestAuth, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/core/header.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!make87_messages/core/header.proto\x12\x14make87_messages.core\x1a\x1fgoogle/protobuf/timestamp.proto\"b\n\x06Header\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0creference_id\x18\x02 \x01(\x04\x12\x13\n\x0b\x65ntity_path\x18\x03 \x01(\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.core.header_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HEADER']._serialized_start=92
  _globals['_HEADER']._serialized_end=190
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Matrix33(_message.Message):
    __slots__ = ("header", "m00", "m01", "m02", "m10", "m11", "m12", "m20", "m21", "m22")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    M00_FIELD_NUMBER: _ClassVar[int]
    M01_FIELD_NUMBER: _ClassVar[int]
    M02_FIELD_NUMBER: _ClassVar[int]
    M10_FIELD_NUMBER: _ClassVar[int]
    M11_FIELD_NUMBER: _ClassVar[int]
    M12_FIELD_NUMBER: _ClassVar[int]
    M20_FIELD_NUMBER: _ClassVar[int]
    M21_FIELD_NUMBER: _ClassVar[int]
    M22_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    m00: float
    m01: float
    m02: float
    m10: float
    m11: float
    m12: float
    m20: float
    m21: float
    m22: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., m00: _Optional[float] = ..., m01: _Optional[float] = ..., m02: _Optional[float] = ..., m10: _Optional[float] = ..., m11: _Optional[float] = ..., m12: _Optional[float] = ..., m20: _Optional[float] = ..., m21: _Optional[float] = ..., m22: _Optional[float] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages.audio import frame_pcm_s16le_pb2 as _frame_pcm_s16le_pb2
from make87_messages.audio import frame_aac_pb2 as _frame_aac_pb2
from make87_messages.audio import frame_opus_pb2 as _frame_opus_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FrameAny(_message.Message):
    __slots__ = ("header", "pcm_s16le", "aac", "opus")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PCM_S16LE_FIELD_NUMBER: _ClassVar[int]
    AAC_FIELD_NUMBER: _ClassVar[int]
    OPUS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    pcm_s16le: _frame_pcm_s16le_pb2.FramePcmS16le
    aac: _frame_aac_pb2.FrameAac
    opus: _frame_opus_pb2.FrameOpus
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., pcm_s16le: _Optional[_Union[_frame_pcm_s16le_pb2.FramePcmS16le, _Mapping]] = ..., aac: _Optional[_Union[_frame_aac_pb2.FrameAac, _Mapping]] = ..., opus: _Optional[_Union[_frame_opus_pb2.FrameOpus, _Mapping]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/audio/any.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.audio import frame_pcm_s16le_pb2 as make87__messages_dot_audio_dot_frame__pcm__s16le__pb2
from make87_messages.audio import frame_aac_pb2 as make87__messages_dot_audio_dot_frame__aac__pb2
from make87_messages.audio import frame_opus_pb2 as make87__messages_dot_audio_dot_frame__opus__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmake87_messages/audio/any.proto\x12\x15make87_messages.audio\x1a!make87_messages/core/header.proto\x1a+make87_messages/audio/frame_pcm_s16le.proto\x1a%make87_messages/audio/frame_aac.proto\x1a&make87_messages/audio/frame_opus.proto\"\xdd\x01\n\x08\x46rameAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x39\n\tpcm_s16le\x18\x02 \x01(\x0b\x32$.make87_messages.audio.FramePcmS16leH\x00\x12.\n\x03\x61\x61\x63\x18\x03 \x01(\x0b\x32\x1f.make87_messages.audio.FrameAacH\x00\x12\x30\n\x04opus\x18\x04 \x01(\x0b\x32 .make87_messages.audio.FrameOpusH\x00\x42\x06\n\x04\x64\x61tab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.audio.any_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FRAMEANY']._serialized_start=218
  _globals['_FRAMEANY']._serialized_end=439
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ImageJPEGWithString(_message.Message):
    __slots__ = ("header", "data", "text")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    TEXT_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    data: bytes
    text: str
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., data: _Optional[bytes] = ..., text: _Optional[str] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ImageRGBA8888(_message.Message):
    __slots__ = ("header", "width", "height", "data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    width: int
    height: int
    data: bytes
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., data: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/transport/auth.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$make87_messages/transport/auth.proto\x12\x1emake87_messages.transport.auth\x1a!make87_messages/core/header.proto\"]\n\tBasicAuth\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"\xdd\x01\n\nDigestAuth\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\r\n\x05realm\x18\x04 \x01(\t\x12\r\n\x05nonce\x18\x05 \x01(\t\x12\x0e\n\x06opaque\x18\x06 \x01(\t\x12\x42\n\talgorithm\x18\x07 \x01(\x0e\x32/.make87_messages.transport.auth.DigestAlgorithm\x12\x0b\n\x03qop\x18\x08 \x01(\t\"J\n\x0b\x42\x65\x61rerToken\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\r\n\x05token\x18\x02 \x01(\t*\x7f\n\x0f\x44igestAlgorithm\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x07\n\x03MD5\x10\x01\x12\x0c\n\x08MD5_SESS\x10\x02\x12\x0b\n\x07SHA_256\x10\x03\x12\x10\n\x0cSHA_256_SESS\x10\x04\x12\x0f\n\x0bSHA_512_256\x10\x05\x12\x14\n\x10SHA_512_256_SESS\x10\x06\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.transport.auth_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_DIGESTALGORITHM']._serialized_start=502
  _globals['_DIGESTALGORITHM']._serialized_end=629
  _globals['_BASICAUTH']._serialized_start=107
  _globals['_BASICAUTH']._serialized_end=200
  _globals['_DIGESTAUTH']._serialized_start=203
  _globals['_DIGESTAUTH']._serialized_end=424
  _globals['_BEARERTOKEN']._serialized_start=426
  _globals['_BEARERTOKEN']._serialized_end=500
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/spatial/translation/translation_3d.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8make87_messages/spatial/translation/translation_3d.proto\x12#make87_messages.spatial.translation\x1a!make87_messages/core/header.proto\"^\n\rTranslation3D\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\t\n\x01x\x18\x02 \x01(\x02\x12\t\n\x01y\x18\x03 \x01(\x02\x12\t\n\x01z\x18\x04 \x01(\x02\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.spatial.translation.translation_3d_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TRANSLATION3D']._serialized_start=132
  _globals['_TRANSLATION3D']._serialized_end=226
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Translation2D(_message.Message):
    __slots__ = ("header", "x", "y")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    X_FIELD_NUMBER: _ClassVar[int]
    Y_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    x: float
    y: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., x: _Optional[float] = ..., y: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/video/any.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.video import frame_h264_pb2 as make87__messages_dot_video_dot_frame__h264__pb2
from make87_messages.video import frame_h265_pb2 as make87__messages_dot_video_dot_frame__h265__pb2
from make87_messages.video import frame_av1_pb2 as make87__messages_dot_video_dot_frame__av1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fmake87_messages/video/any.proto\x12\x15make87_messages.video\x1a!make87_messages/core/header.proto\x1a&make87_messages/video/frame_h264.proto\x1a&make87_messages/video/frame_h265.proto\x1a%make87_messages/video/frame_av1.proto\"\xd4\x01\n\x08\x46rameAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x30\n\x04h264\x18\x02 \x01(\x0b\x32 .make87_messages.video.FrameH264H\x00\x12\x30\n\x04h265\x18\x03 \x01(\x0b\x32 .make87_messages.video.FrameH265H\x00\x12.\n\x03\x61v1\x18\x04 \x01(\x0b\x32\x1f.make87_messages.video.FrameAV1H\x00\x42\x06\n\x04\x64\x61ta\"\xec\x01\n\x0e\x46rameMpegTsAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x36\n\x04h264\x18\x02 \x01(\x0b\x32&.make87_messages.video.FrameMpegTsH264H\x00\x12\x36\n\x04h265\x18\x03 \x01(\x0b\x32&.make87_messages.video.FrameMpegTsH265H\x00\x12\x34\n\x03\x61v1\x18\x04 \x01(\x0b\x32%.make87_messages.video.FrameMpegTsAV1H\x00\x42\x06\n\x04\x64\x61tab\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.video.any_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_FRAMEANY']._serialized_start=213
  _globals['_FRAMEANY']._serialized_end=425
  _globals['_FRAMEMPEGTSANY']._serialized_start=428
  _globals['_FRAMEMPEGTSANY']._serialized_end=664
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ModelOntology(_message.Message):
    __slots__ = ("header", "classes")
    class ClassEntry(_message.Message):
        __slots__ = ("id", "label")
        ID_FIELD_NUMBER: _ClassVar[int]
        LABEL_FIELD_NUMBER: _ClassVar[int]
        id: int
        label: str
        def __init__(self, id: _Optional[int] = ..., label: _Optional[str] = ...) -> None: ...
    HEADER_FIELD_NUMBER: _ClassVar[int]
    CLASSES_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    classes: _containers.RepeatedCompositeFieldContainer[ModelOntology.ClassEntry]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., classes: _Optional[_Iterable[_Union[ModelOntology.ClassEntry, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/image/uncompressed/any.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.image.uncompressed import image_rgb888_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__rgb888__pb2
from make87_messages.image.uncompressed import image_rgba8888_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__rgba8888__pb2
from make87_messages.image.uncompressed import image_yuv420_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__yuv420__pb2
from make87_messages.image.uncompressed import image_yuv422_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__yuv422__pb2
from make87_messages.image.uncompressed import image_yuv444_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__yuv444__pb2
from make87_messages.image.uncompressed import image_nv12_pb2 as make87__messages_dot_image_dot_uncompressed_dot_image__nv12__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,make87_messages/image/uncompressed/any.proto\x12\"make87_messages.image.uncompressed\x1a!make87_messages/core/header.proto\x1a\x35make87_messages/image/uncompressed/image_rgb888.proto\x1a\x37make87_messages/image/uncompressed/image_rgba8888.proto\x1a\x35make87_messages/image/uncompressed/image_yuv420.proto\x1a\x35make87_messages/image/uncompressed/image_yuv422.proto\x1a\x35make87_messages/image/uncompressed/image_yuv444.proto\x1a\x33make87_messages/image/uncompressed/image_nv12.proto\"\xce\x01\n\x0bImageRGBAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x41\n\x06rgb888\x18\x02 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageRGB888H\x00\x12\x45\n\x08rgba8888\x18\x03 \x01(\x0b\x32\x31.make87_messages.image.uncompressed.ImageRGBA8888H\x00\x42\x07\n\x05image\"\xcc\x02\n\x0bImageYUVAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x41\n\x06yuv420\x18\x02 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV420H\x00\x12\x41\n\x06yuv422\x18\x03 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV422H\x00\x12\x41\n\x06yuv444\x18\x04 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV444H\x00\x12=\n\x04nv12\x18\x05 \x01(\x0b\x32-.make87_messages.image.uncompressed.ImageNV12H\x00\x42\x07\n\x05image\"\xd6\x03\n\x0bImageRawAny\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x41\n\x06rgb888\x18\x02 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageRGB888H\x00\x12\x45\n\x08rgba8888\x18\x03 \x01(\x0b\x32\x31.make87_messages.image.uncompressed.ImageRGBA8888H\x00\x12\x41\n\x06yuv420\x18\x04 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV420H\x00\x12\x41\n\x06yuv422\x18\x05 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV422H\x00\x12\x41\n\x06yuv444\x18\x06 \x01(\x0b\x32/.make87_messages.image.uncompressed.ImageYUV444H\x00\x12=\n\x04nv12\x18\x07 \x01(\x0b\x32-.make87_messages.image.uncompressed.ImageNV12H\x00\x42\x07\n\x05imageb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.image.uncompressed.any_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_IMAGERGBANY']._serialized_start=450
  _globals['_IMAGERGBANY']._serialized_end=656
  _globals['_IMAGEYUVANY']._serialized_start=659
  _globals['_IMAGEYUVANY']._serialized_end=991
  _globals['_IMAGERAWANY']._serialized_start=994
  _globals['_IMAGERAWANY']._serialized_end=1464
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/transport/http.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.transport import endpoint_pb2 as make87__messages_dot_transport_dot_endpoint__pb2
from make87_messages.transport import auth_pb2 as make87__messages_dot_transport_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$make87_messages/transport/http.proto\x12\x1emake87_messages.transport.http\x1a!make87_messages/core/header.proto\x1a(make87_messages/transport/endpoint.proto\x1a$make87_messages/transport/auth.proto\"\x91\x04\n\x0bHTTPRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12>\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32,.make87_messages.transport.endpoint.Endpoint\x12:\n\x06method\x18\x03 \x01(\x0e\x32*.make87_messages.transport.http.HTTPMethod\x12I\n\x07headers\x18\x04 \x03(\x0b\x32\x38.make87_messages.transport.http.HTTPRequest.HeadersEntry\x12\x0c\n\x04\x62ody\x18\x05 \x01(\x0c\x12?\n\nbasic_auth\x18\x06 \x01(\x0b\x32).make87_messages.transport.auth.BasicAuthH\x00\x12\x41\n\x0b\x64igest_auth\x18\x07 \x01(\x0b\x32*.make87_messages.transport.auth.DigestAuthH\x00\x12\x43\n\x0c\x62\x65\x61rer_token\x18\x08 \x01(\x0b\x32+.make87_messages.transport.auth.BearerTokenH\x00\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x61uth*g\n\nHTTPMethod\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x07\n\x03GET\x10\x01\x12\x08\n\x04POST\x10\x02\x12\x07\n\x03PUT\x10\x03\x12\n\n\x06\x44\x45LETE\x10\x04\x12\x08\n\x04HEAD\x10\x05\x12\x0b\n\x07OPTIONS\x10\x06\x12\t\n\x05PATCH\x10\x07\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.transport.http_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_HTTPREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPMETHOD']._serialized_start=719
  _globals['_HTTPMETHOD']._serialized_end=822
  _globals['_HTTPREQUEST']._serialized_start=188
  _globals['_HTTPREQUEST']._serialized_end=717
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_start=663
  _globals['_HTTPREQUEST_HEADERSENTRY']._serialized_end=709
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Endpoint(_message.Message):
    __slots__ = ("header", "protocol", "host", "port", "path", "query_params")
    class QueryParamsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    HEADER_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    HOST_FIELD_NUMBER: _ClassVar[int]
    PORT_FIELD_NUMBER: _ClassVar[int]
    PATH_FIELD_NUMBER: _ClassVar[int]
    QUERY_PARAMS_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    protocol: str
    host: str
    port: int
    path: str
    query_params: _containers.ScalarMap[str, str]
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., protocol: _Optional[str] = ..., host: _Optional[str] = ..., port: _Optional[int] = ..., path: _Optional[str] = ..., query_params: _Optional[_Mapping[str, str]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FrameH264(_message.Message):
    __slots__ = ("header", "data", "width", "height", "is_keyframe", "pts", "dts", "duration", "time_base")
    class Fraction(_message.Message):
        __slots__ = ("num", "den")
        NUM_FIELD_NUMBER: _ClassVar[int]
        DEN_FIELD_NUMBER: _ClassVar[int]
        num: int
        den: int
        def __init__(self, num: _Optional[int] = ..., den: _Optional[int] = ...) -> None: ...
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    WIDTH_FIELD_NUMBER: _ClassVar[int]
    HEIGHT_FIELD_NUMBER: _ClassVar[int]
    IS_KEYFRAME_FIELD_NUMBER: _ClassVar[int]
    PTS_FIELD_NUMBER: _ClassVar[int]
    DTS_FIELD_NUMBER: _ClassVar[int]
    DURATION_FIELD_NUMBER: _ClassVar[int]
    TIME_BASE_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    data: bytes
    width: int
    height: int
    is_keyframe: bool
    pts: int
    dts: int
    duration: int
    time_base: FrameH264.Fraction
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., data: _Optional[bytes] = ..., width: _Optional[int] = ..., height: _Optional[int] = ..., is_keyframe: bool = ..., pts: _Optional[int] = ..., dts: _Optional[int] = ..., duration: _Optional[int] = ..., time_base: _Optional[_Union[FrameH264.Fraction, _Mapping]] = ...) -> None: ...

class FrameMpegTsH264(_message.Message):
    __slots__ = ("header", "data")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    data: bytes
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., data: _Optional[bytes] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/datetime/timestamp.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(make87_messages/datetime/timestamp.proto\x12\x18make87_messages.datetime\x1a\x1fgoogle/protobuf/timestamp.proto\":\n\tTimeStamp\x12-\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestampb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.datetime.timestamp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_TIMESTAMP']._serialized_start=103
  _globals['_TIMESTAMP']._serialized_end=161
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/detection/box/box_2d.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.geometry.box import box_2d_pb2 as make87__messages_dot_geometry_dot_box_dot_box__2d__pb2
from make87_messages.geometry.box import box_2d_aligned_pb2 as make87__messages_dot_geometry_dot_box_dot_box__2d__aligned__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*make87_messages/detection/box/box_2d.proto\x12\x1dmake87_messages.detection.box\x1a!make87_messages/core/header.proto\x1a)make87_messages/geometry/box/box_2d.proto\x1a\x31make87_messages/geometry/box/box_2d_aligned.proto\"\x92\x01\n\x05\x42ox2D\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x35\n\x08geometry\x18\x02 \x01(\x0b\x32#.make87_messages.geometry.box.Box2D\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\x10\n\x08\x63lass_id\x18\x04 \x01(\x05\"\xa8\x01\n\x10\x42ox2DAxisAligned\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12@\n\x08geometry\x18\x02 \x01(\x0b\x32..make87_messages.geometry.box.Box2DAxisAligned\x12\x12\n\nconfidence\x18\x03 \x01(\x02\x12\x10\n\x08\x63lass_id\x18\x04 \x01(\x05\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.detection.box.box_2d_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_BOX2D']._serialized_start=207
  _globals['_BOX2D']._serialized_end=353
  _globals['_BOX2DAXISALIGNED']._serialized_start=356
  _globals['_BOX2DAXISALIGNED']._serialized_end=524
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class LogMessage(_message.Message):
    __slots__ = ("header", "level", "message", "source", "file_name", "line_number", "process_id", "thread_id")
    class LogLevel(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
        __slots__ = ()
        DEBUG: _ClassVar[LogMessage.LogLevel]
        INFO: _ClassVar[LogMessage.LogLevel]
        WARNING: _ClassVar[LogMessage.LogLevel]
        ERROR: _ClassVar[LogMessage.LogLevel]
        CRITICAL: _ClassVar[LogMessage.LogLevel]
    DEBUG: LogMessage.LogLevel
    INFO: LogMessage.LogLevel
    WARNING: LogMessage.LogLevel
    ERROR: LogMessage.LogLevel
    CRITICAL: LogMessage.LogLevel
    HEADER_FIELD_NUMBER: _ClassVar[int]
    LEVEL_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SOURCE_FIELD_NUMBER: _ClassVar[int]
    FILE_NAME_FIELD_NUMBER: _ClassVar[int]
    LINE_NUMBER_FIELD_NUMBER: _ClassVar[int]
    PROCESS_ID_FIELD_NUMBER: _ClassVar[int]
    THREAD_ID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    level: LogMessage.LogLevel
    message: str
    source: str
    file_name: str
    line_number: int
    process_id: int
    thread_id: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., level: _Optional[_Union[LogMessage.LogLevel, str]] = ..., message: _Optional[str] = ..., source: _Optional[str] = ..., file_name: _Optional[str] = ..., line_number: _Optional[int] = ..., process_id: _Optional[int] = ..., thread_id: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages.image.uncompressed import image_rgb888_pb2 as _image_rgb888_pb2
from make87_messages.image.uncompressed import image_rgba8888_pb2 as _image_rgba8888_pb2
from make87_messages.image.uncompressed import image_yuv420_pb2 as _image_yuv420_pb2
from make87_messages.image.uncompressed import image_yuv422_pb2 as _image_yuv422_pb2
from make87_messages.image.uncompressed import image_yuv444_pb2 as _image_yuv444_pb2
from make87_messages.image.uncompressed import image_nv12_pb2 as _image_nv12_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ImageRGBAny(_message.Message):
    __slots__ = ("header", "rgb888", "rgba8888")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RGB888_FIELD_NUMBER: _ClassVar[int]
    RGBA8888_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    rgb888: _image_rgb888_pb2.ImageRGB888
    rgba8888: _image_rgba8888_pb2.ImageRGBA8888
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., rgb888: _Optional[_Union[_image_rgb888_pb2.ImageRGB888, _Mapping]] = ..., rgba8888: _Optional[_Union[_image_rgba8888_pb2.ImageRGBA8888, _Mapping]] = ...) -> None: ...

class ImageYUVAny(_message.Message):
    __slots__ = ("header", "yuv420", "yuv422", "yuv444", "nv12")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    YUV420_FIELD_NUMBER: _ClassVar[int]
    YUV422_FIELD_NUMBER: _ClassVar[int]
    YUV444_FIELD_NUMBER: _ClassVar[int]
    NV12_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    yuv420: _image_yuv420_pb2.ImageYUV420
    yuv422: _image_yuv422_pb2.ImageYUV422
    yuv444: _image_yuv444_pb2.ImageYUV444
    nv12: _image_nv12_pb2.ImageNV12
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., yuv420: _Optional[_Union[_image_yuv420_pb2.ImageYUV420, _Mapping]] = ..., yuv422: _Optional[_Union[_image_yuv422_pb2.ImageYUV422, _Mapping]] = ..., yuv444: _Optional[_Union[_image_yuv444_pb2.ImageYUV444, _Mapping]] = ..., nv12: _Optional[_Union[_image_nv12_pb2.ImageNV12, _Mapping]] = ...) -> None: ...

class ImageRawAny(_message.Message):
    __slots__ = ("header", "rgb888", "rgba8888", "yuv420", "yuv422", "yuv444", "nv12")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    RGB888_FIELD_NUMBER: _ClassVar[int]
    RGBA8888_FIELD_NUMBER: _ClassVar[int]
    YUV420_FIELD_NUMBER: _ClassVar[int]
    YUV422_FIELD_NUMBER: _ClassVar[int]
    YUV444_FIELD_NUMBER: _ClassVar[int]
    NV12_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    rgb888: _image_rgb888_pb2.ImageRGB888
    rgba8888: _image_rgba8888_pb2.ImageRGBA8888
    yuv420: _image_yuv420_pb2.ImageYUV420
    yuv422: _image_yuv422_pb2.ImageYUV422
    yuv444: _image_yuv444_pb2.ImageYUV444
    nv12: _image_nv12_pb2.ImageNV12
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., rgb888: _Optional[_Union[_image_rgb888_pb2.ImageRGB888, _Mapping]] = ..., rgba8888: _Optional[_Union[_image_rgba8888_pb2.ImageRGBA8888, _Mapping]] = ..., yuv420: _Optional[_Union[_image_yuv420_pb2.ImageYUV420, _Mapping]] = ..., yuv422: _Optional[_Union[_image_yuv422_pb2.ImageYUV422, _Mapping]] = ..., yuv444: _Optional[_Union[_image_yuv444_pb2.ImageYUV444, _Mapping]] = ..., nv12: _Optional[_Union[_image_nv12_pb2.ImageNV12, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages.video import frame_h264_pb2 as _frame_h264_pb2
from make87_messages.video import frame_h265_pb2 as _frame_h265_pb2
from make87_messages.video import frame_av1_pb2 as _frame_av1_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class FrameAny(_message.Message):
    __slots__ = ("header", "h264", "h265", "av1")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    H264_FIELD_NUMBER: _ClassVar[int]
    H265_FIELD_NUMBER: _ClassVar[int]
    AV1_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    h264: _frame_h264_pb2.FrameH264
    h265: _frame_h265_pb2.FrameH265
    av1: _frame_av1_pb2.FrameAV1
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., h264: _Optional[_Union[_frame_h264_pb2.FrameH264, _Mapping]] = ..., h265: _Optional[_Union[_frame_h265_pb2.FrameH265, _Mapping]] = ..., av1: _Optional[_Union[_frame_av1_pb2.FrameAV1, _Mapping]] = ...) -> None: ...

class FrameMpegTsAny(_message.Message):
    __slots__ = ("header", "h264", "h265", "av1")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    H264_FIELD_NUMBER: _ClassVar[int]
    H265_FIELD_NUMBER: _ClassVar[int]
    AV1_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    h264: _frame_h264_pb2.FrameMpegTsH264
    h265: _frame_h265_pb2.FrameMpegTsH265
    av1: _frame_av1_pb2.FrameMpegTsAV1
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., h264: _Optional[_Union[_frame_h264_pb2.FrameMpegTsH264, _Mapping]] = ..., h265: _Optional[_Union[_frame_h265_pb2.FrameMpegTsH265, _Mapping]] = ..., av1: _Optional[_Union[_frame_av1_pb2.FrameMpegTsAV1, _Mapping]] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages.spatial.translation import translation_2d_pb2 as _translation_2d_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Pose2D(_message.Message):
    __slots__ = ("header", "translation", "rotation")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    ROTATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    translation: _translation_2d_pb2.Translation2D
    rotation: float
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., translation: _Optional[_Union[_translation_2d_pb2.Translation2D, _Mapping]] = ..., rotation: _Optional[float] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/transport/endpoint.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(make87_messages/transport/endpoint.proto\x12\"make87_messages.transport.endpoint\x1a!make87_messages/core/header.proto\"\xfd\x01\n\x08\x45ndpoint\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12\x10\n\x08protocol\x18\x02 \x01(\t\x12\x0c\n\x04host\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\r\x12\x0c\n\x04path\x18\x05 \x01(\t\x12S\n\x0cquery_params\x18\x06 \x03(\x0b\x32=.make87_messages.transport.endpoint.Endpoint.QueryParamsEntry\x1a\x32\n\x10QueryParamsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.transport.endpoint_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_ENDPOINT_QUERYPARAMSENTRY']._loaded_options = None
  _globals['_ENDPOINT_QUERYPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_ENDPOINT']._serialized_start=116
  _globals['_ENDPOINT']._serialized_end=369
  _globals['_ENDPOINT_QUERYPARAMSENTRY']._serialized_start=319
  _globals['_ENDPOINT_QUERYPARAMSENTRY']._serialized_end=369
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: make87_messages/transport/rtsp.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from make87_messages.core import header_pb2 as make87__messages_dot_core_dot_header__pb2
from make87_messages.transport import endpoint_pb2 as make87__messages_dot_transport_dot_endpoint__pb2
from make87_messages.transport import auth_pb2 as make87__messages_dot_transport_dot_auth__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$make87_messages/transport/rtsp.proto\x12\x1emake87_messages.transport.rtsp\x1a!make87_messages/core/header.proto\x1a(make87_messages/transport/endpoint.proto\x1a$make87_messages/transport/auth.proto\"\xbe\x03\n\x0bRTSPRequest\x12,\n\x06header\x18\x01 \x01(\x0b\x32\x1c.make87_messages.core.Header\x12>\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32,.make87_messages.transport.endpoint.Endpoint\x12:\n\x06method\x18\x03 \x01(\x0e\x32*.make87_messages.transport.rtsp.RTSPMethod\x12I\n\x07headers\x18\x04 \x03(\x0b\x32\x38.make87_messages.transport.rtsp.RTSPRequest.HeadersEntry\x12?\n\nbasic_auth\x18\x05 \x01(\x0b\x32).make87_messages.transport.auth.BasicAuthH\x00\x12\x41\n\x0b\x64igest_auth\x18\x06 \x01(\x0b\x32*.make87_messages.transport.auth.DigestAuthH\x00\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x42\x06\n\x04\x61uth*\x98\x01\n\nRTSPMethod\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07OPTIONS\x10\x01\x12\x0c\n\x08\x44\x45SCRIBE\x10\x02\x12\t\n\x05SETUP\x10\x03\x12\x08\n\x04PLAY\x10\x04\x12\t\n\x05PAUSE\x10\x05\x12\x0c\n\x08TEARDOWN\x10\x06\x12\x11\n\rGET_PARAMETER\x10\x07\x12\x11\n\rSET_PARAMETER\x10\x08\x12\n\n\x06RECORD\x10\tb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'make87_messages.transport.rtsp_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_RTSPREQUEST_HEADERSENTRY']._loaded_options = None
  _globals['_RTSPREQUEST_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_RTSPMETHOD']._serialized_start=637
  _globals['_RTSPMETHOD']._serialized_end=789
  _globals['_RTSPREQUEST']._serialized_start=188
  _globals['_RTSPREQUEST']._serialized_end=634
  _globals['_RTSPREQUEST_HEADERSENTRY']._serialized_start=580
  _globals['_RTSPREQUEST_HEADERSENTRY']._serialized_end=626
# @@protoc_insertion_point(module_scope)



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages.geometry.box import box_2d_pb2 as _box_2d_pb2
from make87_messages.geometry.box import box_2d_aligned_pb2 as _box_2d_aligned_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Box2D(_message.Message):
    __slots__ = ("header", "geometry", "confidence", "class_id")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GEOMETRY_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    geometry: _box_2d_pb2.Box2D
    confidence: float
    class_id: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., geometry: _Optional[_Union[_box_2d_pb2.Box2D, _Mapping]] = ..., confidence: _Optional[float] = ..., class_id: _Optional[int] = ...) -> None: ...

class Box2DAxisAligned(_message.Message):
    __slots__ = ("header", "geometry", "confidence", "class_id")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    GEOMETRY_FIELD_NUMBER: _ClassVar[int]
    CONFIDENCE_FIELD_NUMBER: _ClassVar[int]
    CLASS_ID_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    geometry: _box_2d_aligned_pb2.Box2DAxisAligned
    confidence: float
    class_id: int
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., geometry: _Optional[_Union[_box_2d_aligned_pb2.Box2DAxisAligned, _Mapping]] = ..., confidence: _Optional[float] = ..., class_id: _Optional[int] = ...) -> None: ...



from make87_messages.core import header_pb2 as _header_pb2
from make87_messages.spatial.rotation import quaternion_pb2 as _quaternion_pb2
from make87_messages.spatial.translation import translation_3d_pb2 as _translation_3d_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Pose3D(_message.Message):
    __slots__ = ("header", "translation", "rotation")
    HEADER_FIELD_NUMBER: _ClassVar[int]
    TRANSLATION_FIELD_NUMBER: _ClassVar[int]
    ROTATION_FIELD_NUMBER: _ClassVar[int]
    header: _header_pb2.Header
    translation: _translation_3d_pb2.Translation3D
    rotation: _quaternion_pb2.Quaternion
    def __init__(self, header: _Optional[_Union[_header_pb2.Header, _Mapping]] = ..., translation: _Optional[_Union[_translation_3d_pb2.Translation3D, _Mapping]] = ..., rotation: _Optional[_Union[_quaternion_pb2.Quaternion, _Mapping]] = ...) -> None: ...
